# css-typings-loader

Tiny webpack loader to generate TypeScript typings for CSS modules, no complex configuration, support other css preprocessors(less, sass, ...), easy to use.

# Installation

```
npm i css-typings-loader
```

or

```
yarn add css-typings-loader
```

# Prompt

`css-typings-loader` will convert CSS selector(class/id) names to `snake_case` style.

 **When building for the first time, TypeScript may report errors because the typing files has not been generated yet, when finished, there should be no more errors.**

input

```css
.foo { }
.foo-abc { }
.foo_def { }
```

output

```css
.foo { }
.foo_abc { }
.foo_def { }
```

typings

```typescript
export const foo: string;
export const foo_abc: string;
export const foo_def: string;
```

**So, the following two names will be converted to the same one, it will cause unexpected results, should be banned.**

input

```css
.foo-bar { }
.foo_bar { }
```

output

```css
.foo_bar { }
.foo_bar { }
```

typings

```typescript
export const foo_bar: string;
```

# Usage

webpack configuration

```javascript
{
  test: /\.css$/,
  use: [ 'css-loader?modules', 'css-typings-loader' ],
}
```

with less

```js
{
  test: /\.less$/,
  use: [ 'css-loader?modules', 'css-typings-loader', 'less-loader' ],
}
```

React component with TypeScript

```
Home
  - index.tsx
  - style.less
  - style.less.d.ts
```

index.tsx

```tsx
import * as React from 'react'

import * as style from './style.less'

export default function() {
  return (
    <div className={style.home_wrap}>
      <div className={`${style.home_title} ${style.red_title}`}>css-typings-loader</div>
      <h2 className={style.home_info}>Thanks for using!</h2>
    </div>
  )
}
```

style.less

```less
.home-wrap {
  padding: 20px;
  border: 1px solid #ccc;
  border-radius: 10px;
  text-align: center;
}

.home-title {
  font-weight: bold;
  font-size: 30px;
  color: #333;
}

.home-info {
  font-size: 20px;
  color: #999;
  font-style: italic;
}

@media (max-width: 800px) {
  .red-title {
    color: red;
  }
}
```

style.less.d.ts

This file is automatically generated by `css-typings-loader`, please do not edit it manually.

```typescript
export const home_wrap: string;
export const home_title: string;
export const home_info: string;
export const red_title: string;
```

[Here is a complete example](https://github.com/speakout/css-typings-loader/tree/master/example)